@@ -690,7 +690,7 @@ def add_func_scope_types(
     scoped attribute externally accessed elsewhere, whose key is a
     machine-readable name internally generated by this function to uniquely
     refer to the passed tuple of types and whose value is that tuple) to the
-    passed scope *and* return that name.
+    passed scope *and* return that machine-readable name.
 
     This function additionally caches this tuple with the beartypistry
     singleton to reduce space consumption for tuples duplicated across the
@@ -701,7 +701,7 @@ def add_func_scope_types(
     Unlike types, tuples are commonly dynamically constructed on-the-fly by
     various tuple factories (e.g., :attr:`beartype.cave.NoneTypeOr`,
     :attr:`typing.Optional`) and hence have no reliable fully-qualified names.
-    Instead, this closure caches this tuple into the beartypistry under a
+    Instead, this function caches this tuple into the beartypistry under a
     string synthesized as the unique concatenation of:
 
     * The magic substring :data:`TYPISTRY_HINT_NAME_TUPLE_PREFIX`. Since
@@ -733,7 +733,7 @@ def add_func_scope_types(
     Identifying tuples by their hashes enables the beartypistry singleton to
     transparently cache duplicate class tuples with distinct object IDs as the
     same underlying object, reducing space consumption. While hashing tuples
-    does impact time performance, the tangible gains are worth the cost.
+    does impact time performance, the gain in space is worth the cost.
 
     Parameters
     ----------
@@ -794,7 +794,7 @@ def add_func_scope_types(
         TYPISTRY_HINT_NAME_TUPLE_PREFIX,
         bear_typistry,
     )
-    from beartype._util.hint.nonpep.utilhintnonpeptest import (
+    from beartype._util.hint.nonpep.utilnonpeptest import (
         die_unless_hint_nonpep_type)
 
     # If this object is neither a set nor tuple, raise an exception.
@@ -808,7 +808,7 @@ def add_func_scope_types(
         raise BeartypeDecorHintNonPepException(f'{types_label} empty.')
     # Else, this collection is non-empty.
 
-    # If any item of this collection is *NOT* a standard class, raise an
+    # If any item in this collection is *NOT* a standard class, raise an
     # exception.
     for cls in types:
         die_unless_hint_nonpep_type(hint=cls, hint_label=types_label)
