@@ -13,18 +13,19 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
-from beartype.roar import _BeartypeCallHintRaiseException
-from beartype._util.hint.nonpep.utilhintnonpeptest import (
+from beartype.roar._roarexc import _BeartypeCallHintRaiseException
+from beartype._util.hint.nonpep.utilnonpeptest import (
     die_unless_hint_nonpep_tuple)
 from beartype._util.text.utiltextjoin import join_delimited_disjunction_classes
 from beartype._util.text.utiltextlabel import label_class
-from beartype._util.text.utiltextrepr import get_object_representation
+from beartype._util.text.utiltextrepr import represent_object
 from typing import Tuple
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
 
-# ....................{ GETTERS                           }....................
+# ....................{ GETTERS ~ type                    }....................
+#FIXME: Unit test us up.
 def get_cause_object_not_type(pith: object, hint: type) -> str:
     '''
     Human-readable error message describing the failure of the passed arbitrary
@@ -51,27 +52,27 @@ def get_cause_object_not_type(pith: object, hint: type) -> str:
         * This object is actually an instance of this class.
     '''
 
-    # Truncated representation of this pith.
-    pith_repr = get_object_representation(pith)
-
     # If this hint is *NOT* a class, raise an exception.
     if not isinstance(hint, type):
         raise _BeartypeCallHintRaiseException(
             f'Non-PEP type hint {repr(hint)} not class.')
     # Else, this hint is a class.
     #
-    # If this pith is an instance of this class, raise an exception.
+    # If this pith is actually an instance of this class, raise an exception.
     elif isinstance(pith, hint):
         raise _BeartypeCallHintRaiseException(
-            f'{pith_repr} is instance of {repr(hint)}.')
+            f'{represent_object(pith)} instance of '
+            f'non-PEP type hint {repr(hint)}.'
+        )
     # Else, this pith is *NOT* an instance of this type.
 
     # Return a substring describing this failure intended to be embedded in a
     # longer string.
-    return f'value {pith_repr} not {label_class(hint)}'
+    return f'{represent_object(pith)} not {label_class(hint)}'
 
 
-def get_cause_object_not_nonpep_tuple(
+#FIXME: Unit test us up.
+def get_cause_object_not_types(
     pith: object, hint: Tuple[type, ...]) -> str:
     '''
     Human-readable error message describing the failure of the passed arbitrary
@@ -105,24 +106,22 @@ def get_cause_object_not_nonpep_tuple(
     # If this hint is *NOT* a PEP-noncompliant tuple of classes, raise an
     # exception.
     die_unless_hint_nonpep_tuple(
-        hint=hint,
-        is_str_valid=False,
-        exception_cls=_BeartypeCallHintRaiseException,
-    )
+        hint=hint, exception_cls=_BeartypeCallHintRaiseException)
     # Else, this hint is a PEP-noncompliant tuple of classes.
 
-    # Truncated representation of this pith.
-    pith_repr = get_object_representation(pith)
-
     # If this pith is an instance of one or more of the classes listed by this
     # tuple, raise an exception.
     if isinstance(pith, hint):
         raise _BeartypeCallHintRaiseException(
-            f'{pith_repr} is instance of one or more classes in {repr(hint)}.')
+            f'{represent_object(pith)} instance of one or more '
+            f'classes in non-PEP tuple union:\n{repr(hint)}'
+        )
     # Else, this pith is *NOT* an instance of one or more of the classes listed
     # by this tuple.
 
     # Return a substring describing this failure intended to be embedded in a
     # longer string.
     return (
-        f'value {pith_repr} not {join_delimited_disjunction_classes(hint)}')
+        f'{represent_object(pith)} not '
+        f'{join_delimited_disjunction_classes(hint)}'
+    )
