@@ -26,7 +26,23 @@ Python 3.7.0.** If this is *not* the case, importing this submodule raises an
 # ....................{ IMPORTS                           }....................
 from __future__ import annotations
 from beartype import beartype
-from beartype.cave import IntType
+from beartype._cave._cavefast import IntType
+from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
+from beartype_test.a00_unit.data.data_type import decorator
+from collections.abc import Callable
+from typing import List, Union
+
+# ....................{ HINTS                             }....................
+ListStrType = list[str] if IS_PYTHON_AT_LEAST_3_9 else List[str]
+'''
+PEP-compliant type hint matching a list of strings.
+
+This hint is globalized to avoid `PEP 585`_-specific deprecating warnings under
+Python >= 3.9.
+
+.. _PEP 585:
+   https://www.python.org/dev/peps/pep-0585
+'''
 
 # ....................{ CONSTANTS                         }....................
 _MINECRAFT_END_TXT_STANZAS = (
@@ -108,24 +124,191 @@ _MINECRAFT_END_TXT_STANZAS = (
     'Wake up.',
 )
 
-# ....................{ CALLABLES                         }....................
-# Callable intentionally decorated by @beartype.
+# ....................{ CALLABLES ~ module                }....................
+# Callables exercising module-scoped edge cases under PEP 563.
+
+def get_minecraft_end_txt(player_name: str) -> str:
+    '''
+    Callable *not* decorated by :func:`beartype.beartype`.
+
+    The ``test_pep_563()`` unit test tests that :func:`beartype.beartype`
+    silently accepts callables with one or more non-postponed annotations under
+    PEP 563 by manually resolving all postponed annotations on this callable
+    and then manually passing this callable to :func:`beartype.beartype`.
+    '''
+
+    return ''.join(_MINECRAFT_END_TXT_STANZAS).format(player_name=player_name)
+
+
 @beartype
 def get_minecraft_end_txt_stanza(
-    stanza_index: IntType, player_name: str) -> str:
+    player_name: str, stanza_index: IntType) -> str:
+    '''
+    Callable decorated by :func:`beartype.beartype`.
+    '''
+
     return _MINECRAFT_END_TXT_STANZAS[stanza_index].format(
         player_name=player_name)
 
+# ....................{ CALLABLES ~ closure               }....................
+# Callables exercising closure-scoped edge cases under PEP 563.
 
-# Callable intentionally *NOT* decorated by @beartype. The test_pep_563() unit
-# test tests that @beartype emits warnings when passed callables with one or
-# more non-postponed annotations under PEP 563 by manually resolving all
-# postponed annotations on this callable and then manually passing this
-# callable to @beartype.
-def get_minecraft_end_txt(player_name: str) -> str:
-    return ''.join(_MINECRAFT_END_TXT_STANZAS).format(player_name=player_name)
+@beartype
+def get_minecraft_end_txt_closure(player_name: str) -> Callable:
+    '''
+    Callable decorated by :func:`beartype.beartype`, internally declaring and
+    returning a closure also decorated by :func:`beartype.beartype` and
+    annotated by PEP-compliant type hints accessible only as local variables.
+    '''
 
-# ....................{ CALLABLES ~ child limit           }....................
+    # PEP-compliant type hints accessible only as local variables to the
+    # following closure, exercising a significant edge case in PEP 563 support.
+    StringLike = Union[str, int, bytes]
+    ListOfStrings = ListStrType
+
+    # Intentionally delimited by one layer of decoration to exercise edges.
+    @decorator
+    @beartype
+    @decorator
+    def get_minecraft_end_txt_substr(substr: StringLike) -> ListOfStrings:
+        '''
+        Closure decorated by both :func:`beartype.beartype` and one or more
+        decorators that are *not* :func:`beartype.beartype`, annotated by
+        PEP-compliant type hints accessible only as local variables.
+        '''
+
+        return [
+            stanza.format(player_name=player_name)
+            for stanza in _MINECRAFT_END_TXT_STANZAS
+            if str(substr) in stanza
+        ]
+    # print(f'mc.__qualname__: {get_minecraft_end_txt_substr.__qualname__}')
+
+    # Return this closure.
+    return get_minecraft_end_txt_substr
+
+
+@beartype
+def get_minecraft_end_txt_closure_factory(player_name: str) -> Callable:
+    '''
+    Callable decorated by :func:`beartype.beartype`, internally declaring and
+    returning a closure also decorated by :func:`beartype.beartype` and
+    annotated by PEP-compliant type hints accessible only as local variables,
+    internally declaring and returning *another* nested closure also decorated
+    by :func:`beartype.beartype` and annotated by PEP-compliant type hints
+    accessible only as local variables in a manner exercising edge case
+    precedence in scope aggregation.
+    '''
+
+    # PEP-compliant type hints accessible only as local variables to the
+    # following closure, exercising a significant edge case in PEP 563 support.
+    IntLike = Union[float, int]
+    ReturnType = Callable
+    InnerReturnType = ListStrType
+
+    # Intentionally delimited by two layers of decoration to exercise edges.
+    @decorator
+    @decorator
+    @beartype
+    @decorator
+    @decorator
+    def get_minecraft_end_txt_closure_outer(
+        stanza_len_min: IntLike) -> ReturnType:
+        '''
+        Outer closure decorated by :func:`beartype.beartype` and one or more
+        decorators that are *not* :func:`beartype.beartype`, annotated by
+        PEP-compliant type hints accessible only as local variables, internally
+        declaring and returning *another* nested closure also decorated by
+        :func:`beartype.beartype` and annotated by PEP-compliant type hints
+        accessible only as local variables in a manner exercising edge case
+        precedence in scope aggregation.
+        '''
+
+        # PEP-compliant type hints accessible only as local variables to the
+        # following closure, overriding those declared above and again
+        # exercising a significant edge case in PEP 563 support.
+        StringLike = Union[str, bytes]
+        ReturnType = InnerReturnType
+
+        # Intentionally delimited by no layers of decoration to exercise edges.
+        @beartype
+        def get_minecraft_end_txt_closure_inner(
+            stanza_len_max: IntLike,
+            substr: StringLike,
+        ) -> ReturnType:
+            '''
+            Inner closure decorated by :func:`beartype.beartype` and one or
+            more decorators that are *not* :func:`beartype.beartype`, annotated
+            by PEP-compliant type hints accessible only as local variables.
+            '''
+
+            return [
+                stanza.format(player_name=player_name)
+                for stanza in _MINECRAFT_END_TXT_STANZAS
+                if (
+                    len(stanza) >= int(stanza_len_min) and
+                    len(stanza) <= int(stanza_len_max) and
+                    str(substr) in stanza
+                )
+            ]
+
+        # Return this closure.
+        return get_minecraft_end_txt_closure_inner
+    # print(f'mc.__qualname__: {get_minecraft_end_txt_substr.__qualname__}')
+
+    # Return this closure.
+    return get_minecraft_end_txt_closure_outer
+
+# ....................{ CLASSES                           }....................
+# Classes exercising module-scoped edge cases under PEP 563.
+
+#FIXME: We should probably nest this class in a function to exercise
+#everything, but this would seem to suffice for now as an initial foray.
+class MinecraftEndTxtUnscrambler(object):
+    '''
+    Class declaring a method decorated by :func:`beartype.beartype` annotated
+    by PEP-compliant type hints accessible only as class variables.
+    '''
+
+    # PEP-compliant type hints accessible only as class variables to the
+    # following method, exercising a significant edge case in PEP 563 support.
+    NoneIsh = None
+    TextIsh = Union[str, bytes]
+
+    @beartype
+    def __init__(self, unscrambling: TextIsh) -> NoneIsh:
+        '''
+        Method decorated by :func:`beartype.beartype`, annotated by
+        PEP-compliant type hints accessible only as class variables.
+        '''
+
+        _minecraft_end_txt_stanzas_unscrambled = [
+            minecraft_end_txt_stanza.replace('[scrambled]', unscrambling)
+            for minecraft_end_txt_stanza in _MINECRAFT_END_TXT_STANZAS
+            if '[scrambled]' in minecraft_end_txt_stanza
+        ]
+
+        # PEP-compliant type hints accessible only as local variables to the
+        # following closure, exercising an edge case in PEP 563 support.
+        BoolIsh = Union[bool, float, int]
+
+        @beartype
+        def get_minecraft_end_txt_unscrambled_stanza_closure(
+            self, is_stanza_last: BoolIsh) -> self.TextIsh:
+            '''
+            Closure decorated by :func:`beartype.beartype`, annotated by
+            PEP-compliant type hints accessible only as both class and local
+            variables.
+            '''
+
+            return _minecraft_end_txt_stanzas_unscrambled[
+                int(bool(is_stanza_last))]
+
+        # Reuse this closure as a bound method.
+        self.get_minecraft_end_txt_unscrambled_stanza = (
+            get_minecraft_end_txt_unscrambled_stanza_closure)
+
+# ....................{ CALLABLES ~ limit                 }....................
 #FIXME: Hilariously, we can't even unit test whether the
 #beartype._decor._pep563._die_if_hint_repr_exceeds_child_limit() function
 #behaves as expected. Why not? Because some combination of the "typing" module
